"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdRecord = void 0;
const db_1 = require("../utils/db");
const error_1 = require("../utils/error");
const uuid_1 = require("uuid");
class AdRecord {
    constructor(obj) {
        if (!obj.name || obj.name.length > 100 || typeof obj.name != 'string') {
            throw new error_1.ValidationError('The name must not be empty and must not be longer than 100 characters. The name must be of string type.');
        }
        if (obj.description.length > 1000 || typeof obj.description != 'string') {
            throw new error_1.ValidationError('The description must not be longer than 1000 characters. The description must be of string type.');
        }
        if (obj.url.length > 200 || typeof obj.url != 'string') {
            throw new error_1.ValidationError('The URL must not be longer than 200 characters. The URL must be of string type.');
        }
        if (obj.price < 0 || obj.price > 9999999 || typeof obj.price != 'number') {
            throw new error_1.ValidationError('The price may not be less than 0 and more than 9 999 999. The price must be of number type.');
        }
        if (typeof obj.latitude != 'number' || typeof obj.longitude != 'number') {
            throw new error_1.ValidationError('Location cannot be found.');
        }
        if (obj.address.length > 165 || typeof obj.address != 'string') {
            throw new error_1.ValidationError('The address must not be longer than 165 characters. The URL must be of string type.');
        }
        this.id = obj.id;
        this.name = obj.name;
        this.description = obj.description;
        this.url = obj.url;
        this.price = obj.price;
        this.latitude = obj.latitude;
        this.longitude = obj.longitude;
        this.address = obj.address;
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute('SELECT * FROM `ads` WHERE id = :id', {
                id,
            }));
            return results.length === 0 ? null : new AdRecord(results[0]);
        });
    }
    static findAll(name) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute('SELECT * FROM `ads` WHERE name LIKE :search', {
                search: `%${name}%`,
            }));
            return results.map((ad) => {
                const { id, latitude, longitude } = ad;
                return { id, latitude, longitude };
            });
        });
    }
    static findGeoLoc(lat, lot) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute('SELECT * FROM `ads` WHERE latitude BETWEEN :latitude - 0.1 AND :latitude + 0.1 AND longitude BETWEEN :longitude - 0.1 AND :longitude + 0.1', {
                latitude: lat,
                longitude: lot,
            }));
            return results.map((ad) => {
                const { id, latitude, longitude } = ad;
                return { id, latitude, longitude };
            });
        });
    }
    static findAllLocalAds(lat, lot) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute('SELECT * FROM `ads` WHERE latitude BETWEEN :latitude - 0.1 AND :latitude + 0.1 AND longitude BETWEEN :longitude - 0.1 AND :longitude + 0.1', {
                latitude: lat,
                longitude: lot,
            }));
            return results.length === 0 ? null : results.map(ad => new AdRecord(ad));
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            else {
                throw new Error('Cannot insert object that is already inserted');
            }
            yield db_1.pool.execute('INSERT INTO `ads`(`id`, `name`, `description`, `url`, `price`, `latitude`, `longitude`, `address`) VALUES(:id, :name, :description, :url, :price, :latitude, :longitude, :address)', this);
        });
    }
}
exports.AdRecord = AdRecord;
//# sourceMappingURL=ad-record.js.map