"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ad_record_1 = require("../records/ad-record");
const db_1 = require("../utils/db");
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield db_1.pool.end();
}));
const defaultObj = {
    name: 'Test name',
    description: 'Test description',
    url: 'http://test-url.com',
    price: 0,
    latitude: 1,
    longitude: 1,
    address: 'Warszawa'
};
test('AdRecord.getOne return data from database for single entry', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.getOne('test');
    expect(ad).toBeDefined();
    expect(ad.id).toBe('Test');
    expect(ad.name).toBe('Test');
    expect(ad.description).toBe('Test description');
}));
test('AdRecord.getOne return null from database for unexisting entry', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.getOne('fail');
    expect(ad).toBeNull();
}));
test('AdRecord.getAll return array of found elements from database', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('');
    expect(ads).not.toEqual([]);
    expect(ads[0]).toBeDefined();
}));
test('AdRecord.getAll return an array of found elements from the database when the elements have "t" ', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('t');
    expect(ads).not.toEqual([]);
    expect(ads[0]).toBeDefined();
}));
test("AdRecord.getAll return an empty array when the search didn't find any element   ", () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('a!@#$%^&*()');
    expect(ads).toEqual([]);
}));
test('AdRecord.getAll return small amount of data', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('');
    // @ts-ignore
    expect(ads[0].price).toBeUndefined();
    // @ts-ignore
    expect(ads[0].description).toBeUndefined();
}));
test('AdREcord.isert return new UUID', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = new ad_record_1.AdRecord(defaultObj);
    yield ad.insert();
    expect(ad.id).toBeDefined();
    expect(typeof ad.id).toBe('string');
}));
test('AdREcord.isert insert data to database', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = new ad_record_1.AdRecord(defaultObj);
    yield ad.insert();
    const foundAd = yield ad_record_1.AdRecord.getOne(ad.id);
    expect(foundAd).toBeDefined();
    expect(foundAd).not.toBeNull();
    expect(foundAd.id).toBe(ad.id);
}));
//# sourceMappingURL=ad.test.js.map